Crate vortex_fastlanes

Crate vortex_fastlanes 

FastLanes integer encodings for Vortex arrays.

This crate provides SIMD-friendly integer encodings:

  • BitPacked stores fixed-width integer values using the minimum bit width plus optional patches.
  • FoR stores frame-of-reference deltas from a base value.
  • Delta stores adjacent deltas in chunked form.
  • RLE stores repeated runs.

Call initialize to register the encodings and encoding-specific aggregate kernels in a session before deserializing or executing arrays that may contain these encodings.

let session = vortex_array::array_session();
vortex_fastlanes::initialize(&session);

Paper

The original encodings are described in the paper The FastLanes Compression Layout, but are not fully binary compatible. See the underlying fastlanes crate for more details.

Modules

bit_transpose
Fast implementations of the FastLanes 1024-bit transpose.
bitpack_compress
bitpack_decompress
unpack_iter

Structs

BitPacked
BitPackedData
BitPackedDataParts
BitPackedSlots
Delta
DeltaData
A FastLanes-style delta-encoded array of primitive values.
FoR
FoRData
Frame of Reference (FoR) encoded array.
RLE
RLEData

Constants

FL_CHUNK_SIZE

Traits

BitPackedArrayExt
BitPackedArraySlotsExt
Typed array accessors for BitPacked.
FoRArrayExt
RLEArrayExt

Functions

delta_compress
initialize
Initialize fastlanes encodings in the given session.

Type Aliases

BitPackedArray
A BitPacked-encoded Vortex array.
DeltaArray
A Delta-encoded Vortex array.
FoRArray
A FoR-encoded Vortex array.
RLEArray
A RLE-encoded Vortex array.