pub struct RLEData { /* private fields */ }Implementations
Sourceimpl RLEData
impl RLEData
Sourcepub fn encode(
array: ArrayView<'_, Primitive>,
ctx: &mut ExecutionCtx,
) -> VortexResult<RLEArray>
pub fn encode( array: ArrayView<'_, Primitive>, ctx: &mut ExecutionCtx, ) -> VortexResult<RLEArray>
Encodes a primitive array of unsigned integers using FastLanes RLE.
Sourceimpl RLEData
impl RLEData
Sourcepub fn try_new(offset: usize) -> VortexResult<Self>
pub fn try_new(offset: usize) -> VortexResult<Self>
Create a new chunk-based RLE array from its components.
Arguments
values- Unique values from all chunksindices- Chunk-local indices from all chunksvalues_idx_offsets- Start indices for each value chunk.offset- Offset into the first chunklength- Array length
Sourcepub unsafe fn new_unchecked(offset: usize) -> Self
pub unsafe fn new_unchecked(offset: usize) -> Self
Create a new RLEArray without validation.
Safety
The caller must ensure that:
offset + lengthdoes not exceed the length of the indices array- The
indicesarray contains valid indices into chunks of thevaluesarray - The
values_idx_offsetsarray contains valid chunk start offsets
pub fn offset(&self) -> usize