pub struct TransposedBool;Expand description
The array encoding for a boolean bitmap stored in FastLanes-transposed order.
Implementations
Sourceimpl TransposedBool
impl TransposedBool
Sourcepub fn try_new(transposed: ArrayRef) -> VortexResult<TransposedBoolArray>
pub fn try_new(transposed: ArrayRef) -> VortexResult<TransposedBoolArray>
Creates an array from a boolean array already stored in FastLanes-transposed order.
The transposed array may use any encoding (e.g. a lazy slice); it is canonicalized when
this array is executed.
Errors
Returns an error if transposed is not a non-nullable boolean array containing complete
1,024-bit chunks.