RLEArrayExt

Trait RLEArrayExt 

pub trait RLEArrayExt: RLEArraySlotsExt {
    // Provided methods
    fn values_idx_offset(
        &self,
        chunk_idx: usize,
        ctx: &mut ExecutionCtx,
    ) -> usize { ... }
    fn offset(&self) -> usize { ... }
}

Provided Methods

fn values_idx_offset(&self, chunk_idx: usize, ctx: &mut ExecutionCtx) -> usize

Values index offset relative to the first chunk.

Offsets in values_idx_offsets are absolute and need to be shifted by the offset of the first chunk, respective the current slice, in order to make them relative.

fn offset(&self) -> usize

Index offset into the array

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors