FastLanes integer encodings for Vortex arrays.
This crate provides SIMD-friendly integer encodings:
BitPackedstores fixed-width integer values using the minimum bit width plus optional patches.FoRstores frame-of-reference deltas from a base value.Deltastores adjacent deltas in chunked form.RLEstores repeated runs.
Call initialize to register the encodings and encoding-specific aggregate kernels in a
session before deserializing or executing arrays that may contain these encodings.
let session = vortex_array::array_session();
vortex_fastlanes::initialize(&session);Paper
The original encodings are described in the paper The FastLanes Compression Layout, but are not fully binary compatible. See the underlying fastlanes crate for more details.
Modules
- bit_
transpose - Fast implementations of the
FastLanes1024-bit transpose. - bitpack_
compress - bitpack_
decompress - unpack_
iter
Structs
- BitPacked
- BitPacked
Data - BitPacked
Data Parts - BitPacked
Slots - Delta
- Delta
Data - A FastLanes-style delta-encoded array of primitive values.
- FoR
- FoRData
- Frame of Reference (FoR) encoded array.
- RLE
- RLEData
Constants
Traits
- BitPacked
Array Ext - BitPacked
Array Slots Ext - Typed array accessors for
BitPacked. - FoRArray
Ext - RLEArray
Ext
Functions
- delta_
compress - initialize
- Initialize fastlanes encodings in the given session.
Type Aliases
- BitPacked
Array - A
BitPacked-encoded Vortex array. - Delta
Array - A
Delta-encoded Vortex array. - FoRArray
- A
FoR-encoded Vortex array. - RLEArray
- A
RLE-encoded Vortex array.